@@ -27,11 +27,13 @@ if TYPE_CHECKING:
     from tensorflow.keras.layers import Layer  # noqa: F401
 
 
-def convert_from_model_spec(model_spec: ModelSpec,
-                            output_path: str,
-                            output_name: str = 'DNNModel',
-                            spatial_dims: Optional[Tuple[int, int]] = None,
-                            preprocessing: Union['Layer', Sequence['Layer']] = None) -> None:
+def convert_from_model_spec(
+    model_spec: ModelSpec,
+    output_path: str,
+    output_name: str = "DNNModel",
+    spatial_dims: Optional[Tuple[int, int]] = None,
+    preprocessing: Union["Layer", Sequence["Layer"]] = None,
+) -> None:
     """Convert a TensorFlow .pb or TensorFlow Keras model to a CZModel usable in ZEN Intellesis.
 
     Args:
@@ -45,22 +47,30 @@ def convert_from_model_spec(model_spec: ModelSpec,
     os.makedirs(output_path, exist_ok=True)
 
     # Load model if necessary
-    model = model_spec.model if isinstance(model_spec.model, Model) else load_model(model_spec.model)
+    model = (
+        model_spec.model
+        if isinstance(model_spec.model, Model)
+        else load_model(model_spec.model)
+    )
 
     # Convert model
-    keras_to_czmodel.convert(model=model,
-                             model_metadata=model_spec.model_metadata,
-                             output_path=os.path.join(output_path, output_name),
-                             spatial_dims=spatial_dims,
-                             preprocessing=preprocessing)
+    keras_to_czmodel.convert(
+        model=model,
+        model_metadata=model_spec.model_metadata,
+        output_path=os.path.join(output_path, output_name),
+        spatial_dims=spatial_dims,
+        preprocessing=preprocessing,
+    )
 
 
-def convert_from_json_spec(model_spec_path: str,
-                           output_path: str,
-                           output_name: str = 'DNNModel',
-                           spatial_dims: Optional[Tuple[int, int]] = None,
-                           preprocessing: Union['Layer', Sequence['Layer']] = None) -> None:
-    """Converts a TensorFlow .pb model specified in a JSON metadata file to a CZModel that is usable in ZEN Intellesis.
+def convert_from_json_spec(
+    model_spec_path: str,
+    output_path: str,
+    output_name: str = "DNNModel",
+    spatial_dims: Optional[Tuple[int, int]] = None,
+    preprocessing: Union["Layer", Sequence["Layer"]] = None,
+) -> None:
+    """Converts a TensorFlow SavedModel specified in a JSON metadata file to a CZModel that is usable in ZEN Intellesis.
 
     Args:
         model_spec_path: The path to the JSON specification file.
@@ -73,11 +83,13 @@ def convert_from_json_spec(model_spec_path: str,
     parsed_spec = ModelSpec.from_json(model_spec_path)
 
     # Write CZModel to disk
-    convert_from_model_spec(parsed_spec,
-                            output_path,
-                            output_name,
-                            spatial_dims=spatial_dims,
-                            preprocessing=preprocessing)
+    convert_from_model_spec(
+        parsed_spec,
+        output_path,
+        output_name,
+        spatial_dims=spatial_dims,
+        preprocessing=preprocessing,
+    )
 
 
 def main() -> None:
@@ -87,10 +99,21 @@ def main() -> None:
 
     # Define expected arguments
     parser = argparse.ArgumentParser(
-        description='Convert a TensorFlow proto-buffer to a CZModel that can be executed inside ZEN.')
-    parser.add_argument('model_spec', type=dir_file, help='A JSON file containing the model specification.')
-    parser.add_argument('output_path', type=str, help='The path where the generated CZModel will be created.')
-    parser.add_argument('output_name', type=str, help='The name of the generated CZModel.')
+        description="Convert a TensorFlow proto-buffer to a CZModel that can be executed inside ZEN."
+    )
+    parser.add_argument(
+        "model_spec",
+        type=dir_file,
+        help="A JSON file containing the model specification.",
+    )
+    parser.add_argument(
+        "output_path",
+        type=str,
+        help="The path where the generated CZModel will be created.",
+    )
+    parser.add_argument(
+        "output_name", type=str, help="The name of the generated CZModel."
+    )
 
     # Parse arguments
     args = parser.parse_args()
@@ -99,5 +122,5 @@ def main() -> None:
     convert_from_json_spec(args.model_spec, args.output_path, args.output_name)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
