@@ -27,10 +27,11 @@ if TYPE_CHECKING:
 
 class SegmentationClass(NamedTuple):
     """Class representing the metadata of one target class of a segmentation problem."""
+
     name: str
     color: Tuple[int, int, int]
 
-    def to_xml(self, label_value: int, node_name: str = 'Item') -> Element:
+    def to_xml(self, label_value: int, node_name: str = "Item") -> Element:
         """Create an XML representation of the model meta data.
 
         Args:
@@ -44,11 +45,11 @@ class SegmentationClass(NamedTuple):
         model_node = Element(node_name)
 
         # Add attributes
-        model_node.set('colB', str(self.color[2]))
-        model_node.set('colG', str(self.color[1]))
-        model_node.set('colR', str(self.color[0]))
-        model_node.set('LabelValue', str(label_value))
-        model_node.set('Name', self.name)
+        model_node.set("colB", str(self.color[2]))
+        model_node.set("colG", str(self.color[1]))
+        model_node.set("colR", str(self.color[0]))
+        model_node.set("LabelValue", str(label_value))
+        model_node.set("Name", self.name)
 
         return model_node
 
@@ -84,6 +85,7 @@ class ModelMetadata(NamedTuple):
         license_file: The path to a license file that is added to the generated CZModel. Can be absolute or relative to
             the JSON file.
     """
+
     name: str
     color_handling: str
     pixel_type: str
@@ -94,7 +96,7 @@ class ModelMetadata(NamedTuple):
     model_id: uuid.UUID = uuid.uuid4()
 
     @classmethod
-    def from_json(cls, model_metadata: Union[str, Dict]) -> 'ModelMetadata':
+    def from_json(cls, model_metadata: Union[str, Dict]) -> "ModelMetadata":
         """This function parses a model specification JSON file to a ModelMetadata object.
 
         Args:
@@ -106,7 +108,7 @@ class ModelMetadata(NamedTuple):
         spec: Dict
         # Load spec from json if necessary
         if isinstance(model_metadata, str):
-            with open(model_metadata, 'r') as f:
+            with open(model_metadata, "r") as f:
                 spec = json.load(f)
         else:
             spec = model_metadata
@@ -115,25 +117,30 @@ class ModelMetadata(NamedTuple):
         color_gen = iter(ColorGenerator())
 
         # Resolve classes
-        classes_resolved = [SegmentationClass(seg_class, color) for seg_class, color in zip(spec["Classes"], color_gen)]
+        classes_resolved = [
+            SegmentationClass(seg_class, color)
+            for seg_class, color in zip(spec["Classes"], color_gen)
+        ]
 
         return ModelMetadata(
-            name=os.path.basename(spec.get("ModelPath", 'DNN model')),
+            name=os.path.basename(spec.get("ModelPath", "DNN model")),
             color_handling=spec["ColorHandling"],
             pixel_type=spec["PixelType"],
             classes=classes_resolved,
             border_size=spec["BorderSize"],
-            license_file=spec.get("LicenseFile", None)
+            license_file=spec.get("LicenseFile", None),
         )
 
     @classmethod
-    def from_params(cls,
-                    color_handling: str,
-                    pixel_type: str,
-                    classes: List[str],
-                    border_size: int,
-                    name: str = "DNN Model",
-                    license_file: Optional[str] = None) -> 'ModelMetadata':
+    def from_params(
+        cls,
+        color_handling: str,
+        pixel_type: str,
+        classes: List[str],
+        border_size: int,
+        name: str = "DNN Model",
+        license_file: Optional[str] = None,
+    ) -> "ModelMetadata":
         """This function creates ModelMetadata object for a given TensorFlow Keras model.
 
         Args:
@@ -167,7 +174,10 @@ class ModelMetadata(NamedTuple):
         # Create color generator
         color_gen = iter(ColorGenerator())
         # Resolve classes
-        classes_resolved = [SegmentationClass(seg_class, color) for seg_class, color in zip(classes, color_gen)]
+        classes_resolved = [
+            SegmentationClass(seg_class, color)
+            for seg_class, color in zip(classes, color_gen)
+        ]
 
         model_metadata = ModelMetadata(
             name=name,
@@ -175,7 +185,7 @@ class ModelMetadata(NamedTuple):
             pixel_type=pixel_type,
             classes=classes_resolved,
             border_size=border_size,
-            license_file=license_file
+            license_file=license_file,
         )
 
         return model_metadata
@@ -183,45 +193,45 @@ class ModelMetadata(NamedTuple):
     def to_xml(self) -> ElementTree:
         """Creates an XML representation of the model meta data."""
         # Create root node
-        model_node = Element('Model')
-        model_node.set('Version', "3.0.0")
+        model_node = Element("Model")
+        model_node.set("Version", "3.1.0")
 
         # Create model ID
-        id_node = SubElement(model_node, 'Id')
+        id_node = SubElement(model_node, "Id")
         id_node.text = str(self.model_id)
 
         # Add model name
-        name_node = SubElement(model_node, 'ModelName')
+        name_node = SubElement(model_node, "ModelName")
         name_node.text = str(self.name)
 
         # Add status (only 'Trained' is supported for .pb models)
-        status_node = SubElement(model_node, 'Status')
-        status_node.text = 'Trained'
+        status_node = SubElement(model_node, "Status")
+        status_node.text = "Trained"
 
         # Add feature extractor (only 'DeepNeuralNetwork' is supported)
-        feature_extractor_node = SubElement(model_node, 'FeatureExtractor')
-        feature_extractor_node.text = 'DeepNeuralNetwork'
+        feature_extractor_node = SubElement(model_node, "FeatureExtractor")
+        feature_extractor_node.text = "DeepNeuralNetwork"
 
         # Add post-processing node
-        post_processing_node = SubElement(model_node, 'Postprocessing')
+        post_processing_node = SubElement(model_node, "Postprocessing")
         post_processing_node.text = self.post_processing
 
         # Add color handling node
-        color_handling_node = SubElement(model_node, 'ColorHandling')
+        color_handling_node = SubElement(model_node, "ColorHandling")
         color_handling_node.text = self.color_handling
 
         # Add channels (currently only a single channel is supported
-        channels_node = SubElement(model_node, 'Channels')
-        channels_item_node = SubElement(channels_node, 'Item')
-        channels_item_node.set('PixelType', self.pixel_type)
+        channels_node = SubElement(model_node, "Channels")
+        channels_item_node = SubElement(channels_node, "Item")
+        channels_item_node.set("PixelType", self.pixel_type)
 
         # Add Segmentation Classes
-        training_classes_node = SubElement(model_node, 'TrainingClasses')
+        training_classes_node = SubElement(model_node, "TrainingClasses")
         for i, segmentation_class in enumerate(self.classes):
             training_classes_node.append(segmentation_class.to_xml(label_value=i + 1))
 
         # Add border size
-        border_size_node = SubElement(model_node, 'BorderSize')
+        border_size_node = SubElement(model_node, "BorderSize")
         border_size_node.text = str(self.border_size)
 
         return ElementTree(model_node)
@@ -229,11 +239,12 @@ class ModelMetadata(NamedTuple):
 
 class ModelSpec(NamedTuple):
     """Model specification tuple."""
-    model: Union[str, 'Model']
+
+    model: Union[str, "Model"]
     model_metadata: ModelMetadata
 
     @classmethod
-    def from_json(cls, model_spec_path: str) -> 'ModelSpec':
+    def from_json(cls, model_spec_path: str) -> "ModelSpec":
         """This function parses a model specification JSON file to a ModelSpec object.
 
         Args:
@@ -242,7 +253,9 @@ class ModelSpec(NamedTuple):
         Returns:
             A ModelMetadata instance carrying all information to generate a CZModel file.
         """
-        with open(model_spec_path, 'r') as f:
+        with open(model_spec_path, "r") as f:
             spec = json.load(f)
 
-        return ModelSpec(model=spec["ModelPath"], model_metadata=ModelMetadata.from_json(spec))
+        return ModelSpec(
+            model=spec["ModelPath"], model_metadata=ModelMetadata.from_json(spec)
+        )
